@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,13 +25,12 @@
 class QCheckBox;
 class QPushButton;
 class KPluralHandlingSpinBox;
-namespace Gravatar
-{
+namespace Gravatar {
 class GRAVATAR_EXPORT GravatarConfigureSettingsDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit GravatarConfigureSettingsDialog(QWidget *parent = Q_NULLPTR);
+    explicit GravatarConfigureSettingsDialog(QWidget *parent = nullptr);
     ~GravatarConfigureSettingsDialog();
 
 private Q_SLOTS:
